@@ -11,30 +11,30 @@
 # Global variables
 utils::globalVariables(c(
 	 ".", "..Country", "..Organisation", "..SurveyName", "..allDuplicated", "..colAgg", "..colList",
-	 "..columns", "..digits", "..keep", "..key", "..signifDigits", "..sourceColumns",
-	 "..targetAndSourceVariables", "..varToExtract", "..x", "AcousticCategory", "Addition",
-	 "BeamKey", "Constant", "Country", "Cruise", "CruiseKey", "DateTime", "DoorType", "EDSU",
-	 "EchoType", "FishID", "Gear", "GearExp", "HaulNo", "HaulVal", "LengthClass", "LengthCode",
-	 "LocalID", "LogKey", "N", "Number", "NumberAtLength", "Quarter", "ReplaceBy", "SaCategory",
-	 "Scaling", "Ship", "SpecVal", "SpeciesCategoryNumber", "SpeciesCategoryWeight", "SpeciesCode",
-	 "StatRec", "SubsampleWeight", "SubsampledNumber", "Survey", "SweepLngt", "Time",
-	 "TransducerOrientation", "Validity", "VariableName", "WeightMeasurement", "age",
-	 "agingstructure", "ap", "aphia", "bottomdepthstart", "bottomdepthstop", "catCatchWgt",
-	 "catchcount", "catchpartnumber", "catchproducttype", "catchweight", "cc", "cruise", "cw",
-	 "direction", "fishingdepthmax", "fishingdepthmin", "freq", "g", "gear", "gearcondition",
-	 "gearflow", "hv", "inapplicableFormats", "individualweight", "isCrustacean",
-	 "isHerringOrSprat", "isHerringOrSpratOrMackerel", "latitudeend", "latitudestart",
-	 "lenInterval", "lengthmeasurement", "lengthsamplecount", "lengthsampleweight", "level",
-	 "lngtClass", "lngtCode", "longitudeend", "longitudestart", "lsCountTot", "lsc",
+	 "..columns", "..digits", "..keep", "..key", "..parameterNames", "..signifDigits",
+	 "..sourceColumns", "..targetAndSourceVariables", "..toKeep", "..varToExtract", "..x",
+	 "AcousticCategory", "Addition", "BeamKey", "Constant", "Country", "Cruise", "CruiseKey",
+	 "DateTime", "DoorType", "EDSU", "EchoType", "FishID", "Gear", "GearExp", "HaulNo", "HaulVal",
+	 "LengthClass", "LengthCode", "LocalID", "LogKey", "N", "Number", "NumberAtLength", "Quarter",
+	 "ReplaceBy", "SaCategory", "Scaling", "Ship", "SpecVal", "SpeciesCategoryNumber",
+	 "SpeciesCategoryWeight", "SpeciesCode", "StatRec", "SubsampleWeight", "SubsampledNumber",
+	 "Survey", "SweepLngt", "Time", "TransducerOrientation", "Validity", "VariableName",
+	 "WeightMeasurement", "age", "agingstructure", "ap", "aphia", "bottomdepthstart",
+	 "bottomdepthstop", "catCatchWgt", "catchcount", "catchpartnumber", "catchproducttype",
+	 "catchweight", "cc", "cruise", "cw", "direction", "fishingdepthmax", "fishingdepthmin", "freq",
+	 "g", "gear", "gearcondition", "gearflow", "hv", "inapplicableFormats", "individualweight",
+	 "isCrustacean", "isHerringOrSprat", "isHerringOrSpratOrMackerel", "latitudeend",
+	 "latitudestart", "lenInterval", "lengthmeasurement", "lengthsamplecount", "lengthsampleweight",
+	 "level", "lngtClass", "lngtCode", "longitudeend", "longitudestart", "lsCountTot", "lsc",
 	 "maturationstage", "maturity", "meanW", "missionstartdate", "missionstopdate", "ms", "nInd",
 	 "nWithWeight", "nation", "noMeas", "parasite", "platformname", "preferredagereading",
 	 "readability", "reportInMM", "res", "rowIndex", "s", "sampleFac", "samplequality",
 	 "sampletype", "serialnumber", "sex", "sp", "specialstage", "specimenid", "start_time",
 	 "startyear", "station", "stationstartdate", "stationstarttime", "stationstopdate",
-	 "stationstoptime", "stationtype", "stomach", "stoxBioticObject", "subFactor", "subWeight",
-	 "suffixes", "target", "tissuesample", "totWeight", "totalNo", "transceiver", "trawldoorarea",
+	 "stationstoptime", "stomach", "stoxBioticObject", "subFactor", "subWeight", "suffixes",
+	 "target", "tissuesample", "totWeight", "totalNo", "transceiver", "trawldoorarea",
 	 "trawldoorspread", "trawldoortype", "trawldoorweight", "verticaltrawlopening", "winddirection",
-	 "windspeed", "wingspread", "wiredensity", "wirediameter", "wirelength", "..toKeep"))
+	 "windspeed", "wingspread", "wiredensity", "wirediameter", "wirelength"))
 
 .onLoad <- function(libname, pkgname) {
 	# Initiate the RstoxData environment:
