@@ -578,3 +578,91 @@ findVariablesMathcinigVocabularyOne <- function(vocabularyOne, data) {
 }
 
 
+
+orderRowsByKeys <- function(data) {
+	lapply(data, setorderv_numeric, key = "Key")
+}
+
+#' Order a data.table (by reference) by interpreting characters as numeric if possible
+#'
+#' @param dataOne A data.table.
+#' @param by Order by the given columns.
+#' @param key If given and \code{by} is empty, orderr by the columns with names ending with \code{key}.
+#' @param ... Passed on to \code{\link[data.table]{setorderv}}
+#'
+#' @export
+#' 
+setorderv_numeric <- function(dataOne, by = NULL, key = NULL, ...) {
+	
+	# Locate keys:
+	if(!length(by)) {
+		if(length(key)) {
+			by <- names(dataOne)[endsWith(names(dataOne), key)]
+		}
+		else {
+			by <- names(dataOne)
+		}
+	}
+	
+	if(length(by)) {
+		orderKeys <- paste0(by, "OrderedAfterSplitting")
+		
+		# Create keys which are converted to ranks, splitting first and then treatnig individual elemens as numbers if possible:
+		dataOne[, (orderKeys) := lapply(.SD, createOrderKey), .SDcols = by]
+		
+		# Order the rows:
+		data.table::setorderv(dataOne, orderKeys, ...)
+		
+		# Remove the orderKeys:
+		dataOne[, (orderKeys) := NULL]
+	}
+}
+
+
+# Function to decide whether the vector x can be converted to pasted numeric:
+createOrderKey <- function(x, split = "/") {
+	
+	# Split the keys:
+	if(!is.character(x)) {
+		return(x)
+	}
+	splitted <- strsplit(x, split)
+	
+	# Check that all have the same number of elements, that is the same number of splits:
+	if(!all(lengths(splitted) == length(splitted[[1]]))) {
+		return(x)
+	}
+	
+	# Create a data.table off the splitted elements and get the order of these:
+	splittedDT <- data.table::rbindlist(lapply(splitted, as.list))
+	suppressWarnings(splittedDT[, names(splittedDT) := lapply(.SD, as.numeric)])
+	
+	# Only accept if all elements can be converted to numeric:
+	#if(any(is.na(splittedDT))) {
+	
+	# Acccpet if any oof the values are not NA:
+	if(all(is.na(splittedDT))) {
+		return(x)
+	}
+	
+	# Convert to integer ranks:
+	splittedDT[, names(splittedDT) := lapply(.SD, function(y) match(y, sort(unique(y))))]
+
+	# Count the maximum number of digits for each column, and multiply by the cummulative number of digits:
+	numberOfDigits <- splittedDT[, lapply(.SD, max)]
+	numberOfDigits <- nchar(numberOfDigits)
+	exponent <- rev(c(0, cumsum(rev(numberOfDigits))[ -length(numberOfDigits)]))
+	names(exponent) <- names(splittedDT)
+	for(name in names(splittedDT)) {
+		splittedDT[, (name) := get(name) * 10^(exponent[[name]])]
+	}
+	
+	orderKey <- rowSums(splittedDT)
+	
+	
+	#orderOfSplitted <- do.call(order, splittedDT)
+	## Match with a sequence to create integers used as order key:
+	#orderKey <- match(seq_along(x), orderOfSplitted)
+	#
+	return(orderKey)
+}
